.. title:: parselglossy

==========================
parselglossy Documentation
==========================

.. epigraph::

   "What d'you mean? You were there – you heard me —"

   "I heard you speaking Parseltongue," said Ron. "Snake language. You could have been saying anything – no wonder Justin panicked, you sounded like you were egging the snake on or something – it was creepy, you know —"

   -- J. K. Rowling **Harry Potter and the Chamber of Secrets**

   [...] I speak with tongues more than you all;

   -- **1 Corinthians** 14:18

   Parse it on!

   -- Bobson Dugnutt, **Private communication**


Generic input parsing library, speaking in tongues.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   design
   installation
   usage
   contributing
   authors
   history
   modules

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
